@@ -3,6 +3,7 @@
 # License: MIT
 
 from functools import reduce
+import logging
 import os
 import json
 import tempfile
@@ -16,12 +17,12 @@ from .utils import (
     NUL,
     ffmpeg_is_from_brew,
     has_brew,
-    print_info,
-    print_warning,
     run_command,
     win_path_check,
 )
 
+logger = logging.getLogger("ffmpeg-quality-metrics")
+
 
 class FfmpegQualityMetricsError(Exception):
     pass
@@ -124,10 +125,9 @@ class FfmpegQualityMetrics:
             self.temp_files[key] = os.path.join(
                 self.temp_dir, next(tempfile._get_candidate_names()) + f"-{key}.txt"
             )
-            if self.verbose:
-                print_info(
-                    f"Writing temporary {key.upper()} information to: {self.temp_files[key]}"
-                )
+            logger.debug(
+                f"Writing temporary {key.upper()} information to: {self.temp_files[key]}"
+            )
 
         if scaling_algorithm not in self.ALLOWED_SCALERS:
             raise FfmpegQualityMetricsError(
@@ -156,8 +156,7 @@ class FfmpegQualityMetrics:
             if key in filter_list:
                 self.available_filters.append(key)
 
-        if self.verbose:
-            print_info(f"Available filters: {self.available_filters}")
+        logger.debug(f"Available filters: {self.available_filters}")
 
     @staticmethod
     def get_framerate(input_file):
@@ -189,7 +188,7 @@ class FfmpegQualityMetrics:
         dist_framerate = FfmpegQualityMetrics.get_framerate(self.dist)
 
         if ref_framerate != dist_framerate:
-            print_warning(
+            logger.warning(
                 f"ref, dist framerates differ: {ref_framerate}, {dist_framerate}. "
                 "This may result in inaccurate quality metrics. Force an input framerate via the -r option."
             )
@@ -252,8 +251,8 @@ class FfmpegQualityMetrics:
 
         filter_chains = [
             f"[1][0]scale2ref=flags={self.scaling_algorithm}[dist][ref]",
-            "[dist]setpts=PTS-STARTPTS[distpts]",
-            "[ref]setpts=PTS-STARTPTS[refpts]",
+            "[dist]settb=1/AVTB,setpts=PTS-STARTPTS[distpts]",
+            "[ref]settb=1/AVTB,setpts=PTS-STARTPTS[refpts]",
         ]
 
         # generate split filters depending on the number of models
@@ -262,7 +261,9 @@ class FfmpegQualityMetrics:
             for source in ["dist", "ref"]:
                 suffixes = "".join([f"[{source}{n}]" for n in range(1, n_splits + 1)])
                 filter_chains.extend(
-                    [f"[{source}pts]split={n_splits}{suffixes}",]
+                    [
+                        f"[{source}pts]split={n_splits}{suffixes}",
+                    ]
                 )
 
         # special case, only one metric:
@@ -321,7 +322,10 @@ class FfmpegQualityMetrics:
             )
 
     def calc_vmaf(
-        self, model_path=None, phone_model=False, n_threads=DEFAULT_VMAF_THREADS,
+        self,
+        model_path=None,
+        phone_model=False,
+        n_threads=DEFAULT_VMAF_THREADS,
     ):
         """Calculate the VMAF scores for the input files
 
@@ -336,7 +340,7 @@ class FfmpegQualityMetrics:
         Returns:
             dict: VMAF results
         """
-        print_warning(
+        logger.warning(
             "The calc_vmaf() method is deprecated and will be removed eventually. "
             "Please use calc() instead!"
         )
@@ -504,7 +508,7 @@ class FfmpegQualityMetrics:
                     pbar.update(progress - pbar.n)
             return ff.stderr
         else:
-            _, stderr = run_command(cmd, self.dry_run, self.verbose)
+            _, stderr = run_command(cmd, dry_run=self.dry_run)
             return stderr
 
     def calc_ssim_psnr(self):
@@ -516,7 +520,7 @@ class FfmpegQualityMetrics:
         Returns:
             dict: SSIM and PSNR results, each with their own key
         """
-        print_warning(
+        logger.warning(
             "The calc_ssim_psnr() method is deprecated and will be removed eventually. "
             "Please use calc() instead!"
         )
@@ -597,15 +601,22 @@ class FfmpegQualityMetrics:
     @staticmethod
     def get_brewed_vmaf_model_path():
         """
-        Hack to get path for VMAF model from Linuxbrew
+        Hack to get path for VMAF model from Homebrew or Linuxbrew.
+        This works for libvmaf 2.x
 
         Returns:
-            str: the path
+            str or None: the path or None if not found
         """
         stdout, _ = run_command(["brew", "--prefix", "libvmaf"])
         cellar_path = stdout.strip()
 
-        model_path = os.path.join(cellar_path, "share", "model")
+        model_path = os.path.join(cellar_path, "share", "libvmaf", "model")
+
+        if not os.path.isdir(model_path):
+            logger.warning(
+                f"{model_path} does not exist. Are you sure you have installed the most recent version of libvmaf with Homebrew?"
+            )
+            return None
 
         return model_path
 
@@ -620,22 +631,21 @@ class FfmpegQualityMetrics:
         """
         if has_brew() and ffmpeg_is_from_brew():
             # If the user installed ffmpeg using homebrew
-            return os.path.join(
-                # FIXME: change this once VMAF 2.0 is bundled with homebrew!
-                FfmpegQualityMetrics.get_brewed_vmaf_model_path(),
-                "vmaf_v0.6.1.pkl",
-            )
+            model_path = FfmpegQualityMetrics.get_brewed_vmaf_model_path()
+            if model_path is not None:
+                return os.path.join(
+                    model_path,
+                    "vmaf_v0.6.1.json",
+                )
+
+        share_path = os.path.join("/usr", "local", "share", "model")
+        if os.path.isdir(share_path):
+            return os.path.join(share_path, "vmaf_v0.6.1.pkl")
         else:
-            share_path = os.path.join("/usr", "local", "share", "model")
-            if os.path.isdir(share_path):
-                return os.path.join(
-                    share_path, "vmaf_v0.6.1.pkl"
-                )
-            else:
-                # return the bundled file as a fallback
-                return os.path.join(
-                    FfmpegQualityMetrics.DEFAULT_VMAF_MODEL_DIRECTORY, "vmaf_v0.6.1.json"
-                )
+            # return the bundled file as a fallback
+            return os.path.join(
+                FfmpegQualityMetrics.DEFAULT_VMAF_MODEL_DIRECTORY, "vmaf_v0.6.1.json"
+            )
 
     @staticmethod
     def get_supplied_vmaf_models():
@@ -645,7 +655,11 @@ class FfmpegQualityMetrics:
         Returns:
             list: A list of VMAF model names
         """
-        return os.listdir(FfmpegQualityMetrics.DEFAULT_VMAF_MODEL_DIRECTORY)
+        return [
+            f
+            for f in os.listdir(FfmpegQualityMetrics.DEFAULT_VMAF_MODEL_DIRECTORY)
+            if f.endswith(".json") or f.endswith(".pkl")
+        ]
 
     def get_global_stats(self):
         """
