@@ -2,10 +2,10 @@
 # Author: Werner Robitza
 # License: MIT
 
+import logging
 from platform import system as _current_os
 from shutil import which
 import os
-import sys
 import subprocess
 import shlex
 
@@ -17,6 +17,8 @@ IS_NIX = (not IS_WIN) and any(
 )
 NUL = "NUL" if IS_WIN else "/dev/null"
 
+logger = logging.getLogger("ffmpeg-quality-metrics")
+
 
 def win_path_check(path):
     """
@@ -45,30 +47,17 @@ def ffmpeg_is_from_brew():
     return os.path.islink(ffmpeg_path) and "Cellar/ffmpeg" in os.readlink(ffmpeg_path)
 
 
-def print_error(msg):
-    print("ERROR: %s" % msg, file=sys.stderr)
-
-
-def print_warning(msg):
-    print("WARNING: %s" % msg, file=sys.stderr)
-
-
-def print_info(msg):
-    print("INFO: %s" % msg, file=sys.stderr)
-
-
 def quoted_cmd(cmd):
     return " ".join([shlex.quote(c) for c in cmd])
 
 
-def run_command(cmd, dry_run=False, verbose=False, allow_error=False):
+def run_command(cmd, dry_run=False, allow_error=False):
     """
     Run a command directly
     """
-    if dry_run or verbose:
-        print_info(quoted_cmd(cmd))
-        if dry_run:
-            return "", ""
+    logger.debug(quoted_cmd(cmd))
+    if dry_run:
+        return "", ""
 
     process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     stdout, stderr = process.communicate()
@@ -77,5 +66,5 @@ def run_command(cmd, dry_run=False, verbose=False, allow_error=False):
         return stdout.decode("utf-8"), stderr.decode("utf-8")
     else:
         raise RuntimeError(
-            f"error running command: {quoted_cmd(cmd)}\n{stderr.decode('utf-8')}"
+            f"error running command: {quoted_cmd(cmd)}\n{stdout.decode('utf-8')}\n{stderr.decode('utf-8')}"
         )
